@@ -48,11 +48,28 @@ extern void QualifyAlterCollationOwnerStmt(Node *stmt);
 
 /* forward declarations for deparse_table_stmts.c */
 extern char * DeparseAlterTableSchemaStmt(Node *stmt);
+extern char * DeparseAlterTableStmt(Node *node);
 
 extern void QualifyAlterTableSchemaStmt(Node *stmt);
 
 /* forward declarations for deparse_schema_stmts.c */
 extern char * DeparseGrantOnSchemaStmt(Node *stmt);
+extern char * DeparseAlterSchemaRenameStmt(Node *stmt);
+
+/* forward declarations for deparse_statistics_stmts.c */
+extern char * DeparseCreateStatisticsStmt(Node *node);
+extern char * DeparseDropStatisticsStmt(List *nameList, bool ifExists);
+extern char * DeparseAlterStatisticsRenameStmt(Node *node);
+extern char * DeparseAlterStatisticsSchemaStmt(Node *node);
+extern char * DeparseAlterStatisticsStmt(Node *node);
+extern char * DeparseAlterStatisticsOwnerStmt(Node *node);
+
+extern void QualifyCreateStatisticsStmt(Node *node);
+extern void QualifyDropStatisticsStmt(Node *node);
+extern void QualifyAlterStatisticsRenameStmt(Node *node);
+extern void QualifyAlterStatisticsSchemaStmt(Node *node);
+extern void QualifyAlterStatisticsStmt(Node *node);
+extern void QualifyAlterStatisticsOwnerStmt(Node *node);
 
 /* forward declarations for deparse_type_stmts.c */
 extern char * DeparseCompositeTypeStmt(Node *stmt);
@@ -111,4 +128,18 @@ extern char * DeparseDropExtensionStmt(Node *stmt);
 extern char * DeparseAlterExtensionSchemaStmt(Node *stmt);
 extern char * DeparseAlterExtensionStmt(Node *stmt);
 
+/* forward declarations for deparse_database_stmts.c */
+extern char * DeparseAlterDatabaseOwnerStmt(Node *node);
+
+/* forward declarations for deparse_sequence_stmts.c */
+extern char * DeparseDropSequenceStmt(Node *node);
+extern char * DeparseRenameSequenceStmt(Node *node);
+extern char * DeparseAlterSequenceSchemaStmt(Node *node);
+extern char * DeparseAlterSequenceOwnerStmt(Node *node);
+
+/* forward declarations for qualify_sequence_stmt.c */
+extern void QualifyRenameSequenceStmt(Node *node);
+extern void QualifyAlterSequenceSchemaStmt(Node *node);
+extern void QualifyAlterSequenceOwnerStmt(Node *node);
+
 #endif /* CITUS_DEPARSER_H */
