@@ -15,26 +15,6 @@
 
 #include "utils/hsearch.h"
 
-/* pg12 includes this exact implementation of hash_combine */
-#if PG_VERSION_NUM < PG_VERSION_12
-
-/*
- * Combine two hash values, resulting in another hash value, with decent bit
- * mixing.
- *
- * Similar to boost's hash_combine().
- */
-static inline uint32
-hash_combine(uint32 a, uint32 b)
-{
-	a ^= b + 0x9e3779b9 + (a << 6) + (a >> 2);
-	return a;
-}
-
-
-#endif
-
-
 extern void hash_delete_all(HTAB *htab);
 
 /*
@@ -48,4 +28,6 @@ extern void hash_delete_all(HTAB *htab);
 		 (var) != NULL; \
 		 (var) = hash_seq_search(status))
 
+extern void foreach_htab_cleanup(void *var, HASH_SEQ_STATUS *status);
+
 #endif
