@@ -4,7 +4,7 @@
  * Data structures and functions for gathering lock graphs between
  * distributed transactions.
  *
- * Copyright (c) 2017, Citus Data, Inc.
+ * Copyright (c) Citus Data, Inc.
  *
  *-------------------------------------------------------------------------
  */
@@ -14,7 +14,11 @@
 
 
 #include "postgres.h"
+#include "libpq-fe.h"
+
 #include "datatype/timestamp.h"
+#include "distributed/backend_data.h"
+#include "storage/lock.h"
 
 
 /*
@@ -57,6 +61,13 @@ typedef struct WaitGraph
 extern WaitGraph * BuildGlobalWaitGraph(void);
 extern bool IsProcessWaitingForLock(PGPROC *proc);
 extern bool IsInDistributedTransaction(BackendData *backendData);
+extern TimestampTz ParseTimestampTzField(PGresult *result, int rowIndex, int colIndex);
+extern int64 ParseIntField(PGresult *result, int rowIndex, int colIndex);
+
+/* some utility function to parse results */
+extern int64 ParseIntField(PGresult *result, int rowIndex, int colIndex);
+extern bool ParseBoolField(PGresult *result, int rowIndex, int colIndex);
+extern TimestampTz ParseTimestampTzField(PGresult *result, int rowIndex, int colIndex);
 
 
 #endif /* LOCK_GRAPH_H */
