@@ -48,17 +48,18 @@ extern List * GrantOnSchemaDDLCommands(Oid schemaId);
 extern char * PlacementUpsertCommand(uint64 shardId, uint64 placementId, int shardState,
 									 uint64 shardLength, int32 groupId);
 extern void CreateTableMetadataOnWorkers(Oid relationId);
-extern void MarkNodeHasMetadata(const char *nodeName, int32 nodePort, bool hasMetadata);
-extern void MarkNodeMetadataSynced(const char *nodeName, int32 nodePort, bool synced);
 extern BackgroundWorkerHandle * SpawnSyncMetadataToNodes(Oid database, Oid owner);
-extern bool SendOptionalCommandListToWorkerInTransaction(const char *nodeName, int32
-														 nodePort,
-														 const char *nodeUser,
-														 List *commandList);
 extern void SyncMetadataToNodesMain(Datum main_arg);
 extern void SignalMetadataSyncDaemon(Oid database, int sig);
 extern bool ShouldInitiateMetadataSync(bool *lockFailure);
 
+extern List * SequenceDDLCommandsForTable(Oid relationId);
+extern List * GetSequencesFromAttrDef(Oid attrdefOid);
+extern void GetDependentSequencesWithRelation(Oid relationId, List **attnumList,
+											  List **dependentSequenceList, AttrNumber
+											  attnum);
+extern Oid GetAttributeTypeOid(Oid relationId, AttrNumber attnum);
+
 #define DELETE_ALL_NODES "TRUNCATE pg_dist_node CASCADE"
 #define REMOVE_ALL_CLUSTERED_TABLES_COMMAND \
 	"SELECT worker_drop_distributed_table(logicalrelid::regclass::text) FROM pg_dist_partition"
@@ -79,4 +80,8 @@ extern bool ShouldInitiateMetadataSync(bool *lockFailure);
 	"groupid = EXCLUDED.groupid"
 #define METADATA_SYNC_CHANNEL "metadata_sync"
 
+
+/* controlled via GUC */
+extern char *EnableManualMetadataChangesForUser;
+
 #endif /* METADATA_SYNC_H */
