@@ -19,12 +19,14 @@ extern bool PartitionTableNoLock(Oid relationId);
 extern bool IsChildTable(Oid relationId);
 extern bool IsParentTable(Oid relationId);
 extern Oid PartitionParentOid(Oid partitionOid);
-extern char * LongestPartitionName(Oid parentRelationId);
+extern Oid PartitionWithLongestNameRelationId(Oid parentRelationId);
 extern List * PartitionList(Oid parentRelationId);
 extern char * GenerateDetachPartitionCommand(Oid partitionTableId);
 extern char * GenerateAttachShardPartitionCommand(ShardInterval *shardInterval);
 extern char * GenerateAlterTableAttachPartitionCommand(Oid partitionTableId);
 extern char * GeneratePartitioningInformation(Oid tableId);
+extern void FixPartitionConstraintsOnWorkers(Oid relationId);
+extern void FixLocalPartitionConstraints(Oid relationId, int64 shardId);
 
 
 #endif /* MULTI_PARTITIONING_UTILS_H_ */
