@@ -4,7 +4,7 @@
  *
  * Declarations for public utility functions related to reference tables.
  *
- * Copyright (c) 2014-2016, Citus Data, Inc.
+ * Copyright (c) Citus Data, Inc.
  *
  *-------------------------------------------------------------------------
  */
@@ -12,11 +12,18 @@
 #ifndef REFERENCE_TABLE_UTILS_H_
 #define REFERENCE_TABLE_UTILS_H_
 
-extern uint32 CreateReferenceTableColocationId(void);
-extern void ReplicateAllReferenceTablesToNode(char *nodeName, int nodePort);
-extern void DeleteAllReferenceTablePlacementsFromNodeGroup(int32 groupId);
-extern List * ReferenceTableOidList(void);
-extern int CompareOids(const void *leftElement, const void *rightElement);
+#include "postgres.h"
 
+#include "listutils.h"
+
+#include "distributed/metadata_cache.h"
+
+extern void EnsureReferenceTablesExistOnAllNodes(void);
+extern void EnsureReferenceTablesExistOnAllNodesExtended(char transferMode);
+extern uint32 CreateReferenceTableColocationId(void);
+extern void DeleteAllReferenceTablePlacementsFromNodeGroup(int32 groupId);
+extern int CompareOids(const void *leftElement, const void *rightElement);
+extern int ReferenceTableReplicationFactor(void);
+extern void ReplicateAllReferenceTablesToNode(char *nodeName, int nodePort);
 
 #endif /* REFERENCE_TABLE_UTILS_H_ */
