@@ -21,6 +21,9 @@
 /* GUC, determining whether statements sent to remote nodes are logged */
 extern bool LogRemoteCommands;
 
+/* GUC that determines the number of bytes after which remote COPY is flushed */
+extern int RemoteCopyFlushThreshold;
+
 
 /* simple helpers */
 extern bool IsResponseOK(PGresult *result);
