@@ -24,14 +24,70 @@
 #include "executor/tuptable.h"
 #include "nodes/parsenodes.h"
 #include "parser/parse_func.h"
-#if (PG_VERSION_NUM >= PG_VERSION_12)
 #include "optimizer/optimizer.h"
-#endif
 
 #if (PG_VERSION_NUM >= PG_VERSION_13)
 #include "tcop/tcopprot.h"
 #endif
 
+#if PG_VERSION_NUM >= PG_VERSION_14
+#define AlterTableStmtObjType_compat(a) ((a)->objtype)
+#define getObjectTypeDescription_compat(a, b) getObjectTypeDescription(a, b)
+#define getObjectIdentity_compat(a, b) getObjectIdentity(a, b)
+
+/* for MemoryContextMethods->stats */
+#define stats_compat(a, b, c, d, e) stats(a, b, c, d, e)
+#define FuncnameGetCandidates_compat(a, b, c, d, e, f, g) \
+	FuncnameGetCandidates(a, b, c, d, e, f, g)
+#define expand_function_arguments_compat(a, b, c, d) expand_function_arguments(a, b, c, d)
+#define BeginCopyFrom_compat(a, b, c, d, e, f, g, h) BeginCopyFrom(a, b, c, d, e, f, g, h)
+#define standard_ProcessUtility_compat(a, b, c, d, e, f, g, h) \
+	standard_ProcessUtility(a, b, c, d, e, f, g, h)
+#define ProcessUtility_compat(a, b, c, d, e, f, g, h) \
+	ProcessUtility(a, b, c, d, e, f, g, h)
+#define SetTuplestoreDestReceiverParams_compat(a, b, c, d, e, f) \
+	SetTuplestoreDestReceiverParams(a, b, c, d, e, f)
+#define pgproc_statusflags_compat(pgproc) ((pgproc)->statusFlags)
+#define get_partition_parent_compat(a, b) get_partition_parent(a, b)
+#define RelationGetPartitionDesc_compat(a, b) RelationGetPartitionDesc(a, b)
+#define make_simple_restrictinfo_compat(a, b) make_simple_restrictinfo(a, b)
+#define pull_varnos_compat(a, b) pull_varnos(a, b)
+#define pg_get_statisticsobj_worker_compat(a, b, c) pg_get_statisticsobj_worker(a, b, c)
+#else
+#define AlterTableStmtObjType_compat(a) ((a)->relkind)
+#define F_NEXTVAL F_NEXTVAL_OID
+#define ROLE_PG_MONITOR DEFAULT_ROLE_MONITOR
+#define PROC_WAIT_STATUS_WAITING STATUS_WAITING
+#define getObjectTypeDescription_compat(a, b) getObjectTypeDescription(a)
+#define getObjectIdentity_compat(a, b) getObjectIdentity(a)
+
+/* for MemoryContextMethods->stats */
+#define stats_compat(a, b, c, d, e) stats(a, b, c, d)
+#define FuncnameGetCandidates_compat(a, b, c, d, e, f, g) \
+	FuncnameGetCandidates(a, b, c, d, e, g)
+#define expand_function_arguments_compat(a, b, c, d) expand_function_arguments(a, c, d)
+#define VacOptValue VacOptTernaryValue
+#define VACOPTVALUE_UNSPECIFIED VACOPT_TERNARY_DEFAULT
+#define VACOPTVALUE_DISABLED VACOPT_TERNARY_DISABLED
+#define VACOPTVALUE_ENABLED VACOPT_TERNARY_ENABLED
+#define CopyFromState CopyState
+#define BeginCopyFrom_compat(a, b, c, d, e, f, g, h) BeginCopyFrom(a, b, d, e, f, g, h)
+#define standard_ProcessUtility_compat(a, b, c, d, e, f, g, h) \
+	standard_ProcessUtility(a, b, d, e, f, g, h)
+#define ProcessUtility_compat(a, b, c, d, e, f, g, h) ProcessUtility(a, b, d, e, f, g, h)
+#define COPY_FRONTEND COPY_NEW_FE
+#define SetTuplestoreDestReceiverParams_compat(a, b, c, d, e, f) \
+	SetTuplestoreDestReceiverParams(a, b, c, d)
+#define pgproc_statusflags_compat(pgproc) \
+	((&ProcGlobal->allPgXact[(pgproc)->pgprocno])->vacuumFlags)
+#define get_partition_parent_compat(a, b) get_partition_parent(a)
+#define RelationGetPartitionDesc_compat(a, b) RelationGetPartitionDesc(a)
+#define PQ_LARGE_MESSAGE_LIMIT 0
+#define make_simple_restrictinfo_compat(a, b) make_simple_restrictinfo(b)
+#define pull_varnos_compat(a, b) pull_varnos(b)
+#define pg_get_statisticsobj_worker_compat(a, b, c) pg_get_statisticsobj_worker(a, c)
+#endif
+
 #if PG_VERSION_NUM >= PG_VERSION_13
 #define lnext_compat(l, r) lnext(l, r)
 #define list_delete_cell_compat(l, c, p) list_delete_cell(l, c)
@@ -125,87 +181,6 @@ FileCompatFromFileStart(File fileDesc)
 }
 
 
-#else /* pre PG12 */
-#define CreateTableSlotForRel(rel) MakeSingleTupleTableSlot(RelationGetDescr(rel))
-#define table_open(r, l) heap_open(r, l)
-#define table_openrv(r, l) heap_openrv(r, l)
-#define table_openrv_extended(r, l, m) heap_openrv_extended(r, l, m)
-#define table_close(r, l) heap_close(r, l)
-#define QTW_EXAMINE_RTES_BEFORE QTW_EXAMINE_RTES
-#define MakeSingleTupleTableSlotCompat(tupleDesc, tts_opts) \
-	MakeSingleTupleTableSlot(tupleDesc)
-#define NextCopyFromCompat(cstate, econtext, values, nulls) \
-	NextCopyFrom(cstate, econtext, values, nulls, NULL)
-
-/*
- * In PG12 GetSysCacheOid requires an oid column,
- * whereas beforehand the oid column was implicit with WITH OIDS
- */
-#define GetSysCacheOid1Compat(cacheId, oidcol, key1) \
-	GetSysCacheOid1(cacheId, key1)
-#define GetSysCacheOid2Compat(cacheId, oidcol, key1, key2) \
-	GetSysCacheOid2(cacheId, key1, key2)
-#define GetSysCacheOid3Compat(cacheId, oidcol, key1, key2, key3) \
-	GetSysCacheOid3(cacheId, key1, key2, key3)
-#define GetSysCacheOid4Compat(cacheId, oidcol, key1, key2, key3, key4) \
-	GetSysCacheOid4(cacheId, key1, key2, key3, key4)
-
-#define LOCAL_FCINFO(name, nargs) \
-	FunctionCallInfoData name ## data; \
-	FunctionCallInfoData *name = &name ## data
-
-#define fcGetArgValue(fc, n) ((fc)->arg[n])
-#define fcGetArgNull(fc, n) ((fc)->argnull[n])
-#define fcSetArgExt(fc, n, val, is_null) \
-	(((fc)->argnull[n] = (is_null)), ((fc)->arg[n] = (val)))
-
-typedef struct
-{
-	File fd;
-} FileCompat;
-
-static inline int
-FileWriteCompat(FileCompat *file, char *buffer, int amount, uint32 wait_event_info)
-{
-	return FileWrite(file->fd, buffer, amount, wait_event_info);
-}
-
-
-static inline int
-FileReadCompat(FileCompat *file, char *buffer, int amount, uint32 wait_event_info)
-{
-	return FileRead(file->fd, buffer, amount, wait_event_info);
-}
-
-
-static inline FileCompat
-FileCompatFromFileStart(File fileDesc)
-{
-	FileCompat fc = {
-		.fd = fileDesc,
-	};
-
-	return fc;
-}
-
-
-/*
- * postgres 11 equivalent for a function with the same name in postgres 12+.
- */
-static inline bool
-table_scan_getnextslot(HeapScanDesc scan, ScanDirection dir, TupleTableSlot *slot)
-{
-	HeapTuple tuple = heap_getnext(scan, ForwardScanDirection);
-	if (tuple == NULL)
-	{
-		return false;
-	}
-
-	ExecStoreTuple(tuple, slot, InvalidBuffer, false);
-	return true;
-}
-
-
 #endif /* PG12 */
 
 #define fcSetArg(fc, n, value) fcSetArgExt(fc, n, value, false)
