@@ -35,7 +35,6 @@
 #define JOB_SCHEMA_PREFIX "pg_merge_job_"
 #define TASK_FILE_PREFIX "task_"
 #define TASK_TABLE_PREFIX "task_"
-#define TABLE_FILE_PREFIX "table_"
 #define PARTITION_FILE_PREFIX "p_"
 #define ATTEMPT_FILE_SUFFIX ".attempt"
 #define MERGE_TABLE_SUFFIX "_merge"
@@ -123,6 +122,7 @@ extern int32 ArrayObjectCount(ArrayType *arrayObject);
 extern FmgrInfo * GetFunctionInfo(Oid typeId, Oid accessMethodId, int16 procedureId);
 extern uint64 ExtractShardIdFromTableName(const char *tableName, bool missingOk);
 extern void RepartitionCleanupJobDirectories(void);
+extern void SetDefElemArg(AlterSeqStmt *statement, const char *name, Node *arg);
 
 
 /* Function declarations shared with the master planner */
@@ -144,7 +144,6 @@ extern Node * ParseTreeRawStmt(const char *ddlCommand);
 
 /* Function declarations for applying distributed execution primitives */
 extern Datum worker_fetch_partition_file(PG_FUNCTION_ARGS);
-extern Datum worker_fetch_query_results_file(PG_FUNCTION_ARGS);
 extern Datum worker_apply_shard_ddl_command(PG_FUNCTION_ARGS);
 extern Datum worker_range_partition_table(PG_FUNCTION_ARGS);
 extern Datum worker_hash_partition_table(PG_FUNCTION_ARGS);
@@ -163,5 +162,7 @@ extern Datum worker_find_block_local_path(PG_FUNCTION_ARGS);
 /* Function declaration for calculating hashed value */
 extern Datum worker_hash(PG_FUNCTION_ARGS);
 
+/* Function declaration for calculating nextval() in worker */
+extern Datum worker_nextval(PG_FUNCTION_ARGS);
 
 #endif   /* WORKER_PROTOCOL_H */
