@@ -37,15 +37,25 @@ extern void SendCommandToWorkersAsUser(TargetWorkerSet targetWorkerSet,
 									   const char *nodeUser, const char *command);
 extern void SendCommandToWorkerAsUser(const char *nodeName, int32 nodePort,
 									  const char *nodeUser, const char *command);
+extern bool SendOptionalCommandListToWorkerOutsideTransaction(const char *nodeName,
+															  int32 nodePort,
+															  const char *nodeUser,
+															  List *commandList);
+extern bool SendOptionalCommandListToWorkerInCoordinatedTransaction(const char *nodeName,
+																	int32 nodePort,
+																	const char *nodeUser,
+																	List *commandList);
 extern void SendCommandToWorkersWithMetadata(const char *command);
 extern void SendBareCommandListToMetadataWorkers(List *commandList);
-extern int SendBareOptionalCommandListToAllWorkersAsUser(List *commandList,
-														 const char *user);
 extern void EnsureNoModificationsHaveBeenDone(void);
-extern void SendCommandListToWorkerInSingleTransaction(const char *nodeName,
-													   int32 nodePort,
-													   const char *nodeUser,
-													   List *commandList);
+extern void SendCommandListToWorkerOutsideTransaction(const char *nodeName,
+													  int32 nodePort,
+													  const char *nodeUser,
+													  List *commandList);
+extern void SendCommandListToWorkerInCoordinatedTransaction(const char *nodeName,
+															int32 nodePort,
+															const char *nodeUser,
+															List *commandList);
 extern void SendCommandToWorkersOptionalInParallel(TargetWorkerSet targetWorkerSet,
 												   const char *command,
 												   const char *user);
